@@ -69,14 +69,14 @@ class NOOPSubmissionTask(SubmissionTask):
 
 class ExceptionSubmissionTask(SubmissionTask):
     def _submit(self, transfer_future, executor=None, tasks_to_submit=None,
-                additional_callbacks=None):
+                additional_callbacks=None, exception=TaskFailureException):
         if executor and tasks_to_submit:
             for task_to_submit in tasks_to_submit:
                 self._transfer_coordinator.submit(executor, task_to_submit)
         if additional_callbacks:
             for callback in additional_callbacks:
                 callback()
-        raise TaskFailureException()
+        raise exception()
 
 
 class StatusRecordingTransferCoordinator(TransferCoordinator):
@@ -164,6 +164,16 @@ class TestSubmissionTask(BaseSubmissionTaskTest):
         with self.assertRaises(TaskFailureException):
             self.transfer_future.result()
 
+    def test_catches_and_sets_keyboard_interrupt_exception_from_submit(self):
+        self.main_kwargs['exception'] = KeyboardInterrupt
+        submission_task = self.get_task(
+            ExceptionSubmissionTask, main_kwargs=self.main_kwargs)
+        submission_task()
+
+        self.assertEqual(self.transfer_coordinator.status, 'failed')
+        with self.assertRaises(KeyboardInterrupt):
+            self.transfer_future.result()
+
     def test_calls_done_callbacks_on_exception(self):
         submission_task = self.get_task(
             ExceptionSubmissionTask, main_kwargs=self.main_kwargs)
@@ -711,7 +721,8 @@ class TestCompleteMultipartUploadTask(BaseMultipartTaskTest):
                 'bucket': self.bucket,
                 'key': self.key,
                 'upload_id': upload_id,
-                'parts': parts
+                'parts': parts,
+                'extra_args': {}
             }
         )
         self.stubber.add_response(
@@ -727,3 +738,32 @@ class TestCompleteMultipartUploadTask(BaseMultipartTaskTest):
         )
         task()
         self.stubber.assert_no_pending_responses()
+
+    def test_includes_extra_args(self):
+        upload_id = 'my-id'
+        parts = [{'ETag': 'etag', 'PartNumber': 0}]
+        task = self.get_task(
+            CompleteMultipartUploadTask,
+            main_kwargs={
+                'client': self.client,
+                'bucket': self.bucket,
+                'key': self.key,
+                'upload_id': upload_id,
+                'parts': parts,
+                'extra_args': {'RequestPayer': 'requester'}
+            }
+        )
+        self.stubber.add_response(
+            method='complete_multipart_upload',
+            service_response={},
+            expected_params={
+                'Bucket': self.bucket, 'Key': self.key,
+                'UploadId': upload_id,
+                'MultipartUpload': {
+                    'Parts': parts
+                },
+                'RequestPayer': 'requester'
+            }
+        )
+        task()
+        self.stubber.assert_no_pending_responses()
